aboutsummaryrefslogtreecommitdiff
path: root/odb/transaction.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'odb/transaction.hxx')
-rw-r--r--odb/transaction.hxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/odb/transaction.hxx b/odb/transaction.hxx
index 71d17eb..a069209 100644
--- a/odb/transaction.hxx
+++ b/odb/transaction.hxx
@@ -24,7 +24,7 @@ namespace odb
explicit
transaction (transaction_impl*);
// Unless the transaction has already been finilized (explicitly
// committed or rolled back), the destructor will roll it back.
//
~transaction ();
@@ -62,7 +62,7 @@ namespace odb
transaction& operator= (const transaction&);
protected:
- bool finilized_;
+ bool finalized_;
transaction_impl* impl_;
};
@@ -24,7 +24,7 @@ namespace odb
explicit
transaction (transaction_impl*);
- // Unless the transaction has already been finilized (explicitly
+ // Unless the transaction has already been finalized (explicitly
// committed or rolled back), the destructor will roll it back.
//